<div id="quickfind-container">
  <input id="quickfind" placeholder="Quick Find ..." />
</div>
<div id="globaltoc" class="toc">
  {{ toctree(includehidden=True, titles_only=True, collapse=False, maxdepth=-1) }}
</div>

