<div class="dropdown">
  <button class="btn btn-secondary dropdown-toggle version-select" type="button" tabindex="0" id="dropdownMenuButton" data-toggle="dropdown" aria-haspopup="true" aria-expanded="false">
    Skuid Version: v{{ theme_version }} <span class="caret"></span></button>
  </button>
  <div class="dropdown-menu" aria-labelledby="dropdownMenuButton"></div>
</div>