<header class="navbar">
    <a class="navbar-brand" href="{{ pathto(master_doc) }}">
        <img src="{{ pathto('_static' ~ theme_logo, 1) }}" alt="{{ theme_logo_alt }}">
    </a>
    {% block navbarsearch %}
        {% include "navbarsearchbox.html" %}
    {% endblock %}
    <ul class="navbar-nav">
    {% if theme_navbar_dropdowns %}
    <li role="toolbar" aria-haspopup="true" class="nav-dropdown" tabindex="0">
        {% if theme_navbar_name %}
            {{theme_navbar_name}}
        {% else %}
            Documentation
        {% endif %}
      <ul aria-hidden="true" aria-label="submenu" id="guides" class="nav-sub-menu">
       {%- for dropdown in theme_navbar_dropdowns %}<li><a href="{{ pathto(*dropdown[1:]) }}">{{ dropdown[0] }}</a></li>{%- endfor %}
      </ul>
    </li>
    {% endif %}
    {% if theme_navbar_links %}
        {%- for link in theme_navbar_links %}<li><a href="{{ pathto(*link[1:]) }}">{{ link[0] }}</a></li>{%- endfor %}
    {% endif %}
    </ul>
</header>