{%- if pagename != "search" %}
<form action="{{ pathto('search') }}" method="get" class="navbar-search-form" style="padding-bottom: 1rem;">
<div id="searchbar">
  <label for="navbar-search" class="sr-only">Search Skuid documentation</label>
  <div class="search-icon" style=""></div>
<input type="text" name="q" id="navbar-search" class="search" placeholder="Search" style="
    \: rgba(0,0,0,.8);
">

  <input type="hidden" name="check_keywords" value="yes">
  <input type="hidden" name="area" value="default">
  </div>
</form>
{%- endif %}
