{# Switch to icon instead of text in `sm` view size for BS3 only. #}
{%- if prev %}
  <li>
    <a href="{{ prev.link|e }}" title="{{ _('Previous Chapter: ') + prev.title|striptags }}">
      <span class="glyphicon glyphicon-chevron-left visible-sm"></span>
      <span class="hidden-sm hidden-tablet">{{ "&laquo;"|safe }} {{ prev.title|striptags|truncate(length=16, killwords=True) }}</span>
    </a>
  </li>
{%- endif %}
{%- if next %}
  <li>
    <a href="{{ next.link|e }}" title="{{ _('Next Chapter: ') + next.title|striptags }}">
      <span class="glyphicon glyphicon-chevron-right visible-sm"></span>
      <span class="hidden-sm hidden-tablet">{{ next.title|striptags|truncate(length=16, killwords=True) }} {{ "&raquo;"|safe }}</span>
    </a>
  </li>
{%- endif %}
